CHANGELOG
=========
0.4
    Merged in publishsubscribe, added attr_name getters, set loggers to INFO by
    default
0.3
    Added documentation, updated meta files
0.2
    Added modeling
0.1
    Initial release
